@@ -43,6 +43,7 @@ class ZoneType(Enum):
     CARBON_MONOXIDE   = 14
     PROA7_MEDICAL     = 15
     FIRE_W_VERIFICATION = 16  # must trigger twice to cause an alarm
+    LYRIC_KEYPAD = 50
     LYRIC_LOCAL_ALARM = 89
 
     # According to the VISTA docs, these can be programmed via downloader software
@@ -156,8 +157,11 @@ class TotalConnectZone:
 
     def is_type_fire(self):
         """Return true if zone type is fire or smoke."""
-        # TODO: why is ZoneType.MONITOR here? it's not a fire or smoke zone type
-        return self.zone_type_id in (ZoneType.FIRE_SMOKE, ZoneType.MONITOR)
+        return self.zone_type_id == ZoneType.FIRE_SMOKE
+
+    def is_type_temperature(self):
+        """Return true if zone monitors the temperature."""
+        return self.zone_type_id == ZoneType.MONITOR
 
     def is_type_carbon_monoxide(self):
         """Return true if zone type is carbon monoxide."""
@@ -167,6 +171,10 @@ class TotalConnectZone:
         """Return true if zone type is medical."""
         return self.zone_type_id == ZoneType.PROA7_MEDICAL
 
+    def is_type_keypad(self):
+        """Return true if zone type is keypad."""
+        return self.zone_type_id == ZoneType.LYRIC_KEYPAD
+
     def _update(self, zone):
         """Update the zone."""
         assert zone
